# general info
NAME="httpd"
DESC="Apache HTTP server"
VERSION="2.4.58"

# required files
FILES=(
  "https://archive.apache.org/dist/httpd/httpd-${VERSION}.tar.bz2"
  "httpd-${VERSION}-layout.patch"
  "httpd.service"
)
HASHES=(
  "30377ec4d7fb8361e1d1f2ab3158b467"
  "507e758614da8b0222aedb8a92d2222246f513428166de841e435dbb254bb2b6"
  "f574bac6d5f398e7a649fc0e1ca66ff01ad4ef34dac71258e93d8a9d9a2b3960"
)

# install and build depends
DEPENDS=(
  "apr-util" "nghttp2" "openssl"
  "brotli" "jansson" "libxml2" 
  "libxcrypt" "pcre2" "zlib"
  "lua" "lynx" "openldap"
)
BUILD=("systemd")

PACKAGE(){
  tar xf "${NAME}-${VERSION}.tar.bz2"
  cd "${NAME}-${VERSION}"

  patch -Np1 -i "../httpd-${VERSION}-layout.patch"

  sed '/dir.*CFG_PREFIX/s@^@#@' -i support/apxs.in

  sed -e '/HTTPD_ROOT/s:${ap_prefix}:/etc/httpd:'     \
    -e '/SERVER_CONFIG_FILE/s:${rel_sysconfdir}/::'   \
    -e '/AP_TYPES_CONFIG_FILE/s:${rel_sysconfdir}/::' \
    -i configure

  sed -e '/encoding.h/a # include <libxml/xmlstring.h>' \
    -i modules/filters/mod_xml2enc.c

  ./configure --enable-authnz-fcgi                           \
            --enable-layout=MatterLinux                      \
            --enable-mods-shared="all cgi"                   \
            --enable-mpms-shared=all                         \
            --enable-suexec=                                 \
            --with-apr=/usr/bin/apr-1-config                 \
            --with-apr-util=/usr/bin/apu-1-config            \
            --with-suexec-caller=httpd                       \
            --with-suexec-docroot=/srv/www                   \
            --with-suexec-logfile=/var/log/httpd/suexec.log  \
            --with-suexec-bin=/usr/bin/suexec                \
            --with-suexec-uidmin=99 --with-suexec-gidmin=99  \
            --with-suexec-userdir=public_html                \
            --enable-ldap --enable-cache --enable-ssl        \
            --with-ssl --enable-proxy --enable-proxy-connect \
            --enable-proxy-http --enable-proxy-ftp           \
            --enable-cern-meta --enable-lua --enable-xml2enc \
            --enable-http2 --enable-brotli --enable-systemd  \
            --with-pcre2
  make
  make DESTDIR="${ROOTDIR}" install
  install -Dm644 ../httpd.service "${ROOTDIR}/usr/lib/systemd/system/httpd.service"
  install -Ddm755 "${ROOTDIR}/srv/www"

  cd .. && rm -r "${NAME}-${VERSION}"
}

INSTALL(){
  groupadd -g 1025 httpd 
  useradd -c "Apache HTTP server" -d /srv/www -g httpd \
        -s /bin/false -u 1025 httpd
  chown -v -R httpd:httpd /srv/www
  exit 0
}
